package realityrpg.client.main;

import com.google.android.maps.*;

//import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnDismissListener;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.text.Editable;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.*;
import java.util.*;
import android.location.*;
import realityrpg.client.net.Connection;
import realityrpg.common.entities.RPGGame;
import realityrpg.common.entities.RPGItemsOverlay;
import realityrpg.client.main.R;

public class MainActivity extends MapActivity implements LocationListener, OnDismissListener {
    LinearLayout linearLayout;
    MapView mapView;
    
    List<Overlay> mapOverlays;
    Drawable drawable;
    RPGItemsOverlay itemizedOverlay;
    
    Location myLocation;
    LocationManager lm;
    
    Connection connection;
    Thread connectionThread;
    
    RPGGame game;
    
    final int MENU_NEW_GAME = 0;
    final int MENU_QUIT = 1;
    
    final int DIALOG_SELECT_SERVER = 0;
        
	@Override
	protected boolean isRouteDisplayed() {
	    return false;
	}

	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
    	
		lm = (LocationManager) getSystemService(LOCATION_SERVICE);    
        lm.requestLocationUpdates(LocationManager.GPS_PROVIDER, 3000, 0, this);
        
        mapView = (MapView) findViewById(R.id.mapview);
        mapView.setBuiltInZoomControls(true);
        
        mapOverlays = mapView.getOverlays();
        drawable = this.getResources().getDrawable(R.drawable.player);
        drawable.setAlpha(196);
        itemizedOverlay = new RPGItemsOverlay(drawable);
        
        Location location = lm.getLastKnownLocation(LOCATION_SERVICE);
        drawIcon(location);
    }


	@Override
	public void onLocationChanged(Location location) {
        itemizedOverlay.removeLastOverlay();
        drawIcon(location);
        
    	myLocation = location;

    	if(connection != null)
    		connection.sendString(location.getLatitude() + ", " + location.getLongitude());
	}

	private void drawIcon(Location location) {
		if(location != null) {
			int latitude = (int)(location.getLatitude()*1000000);
	        int longitude = (int)(location.getLongitude()*1000000);
	        
	    	GeoPoint point = new GeoPoint(latitude, longitude);
	    	OverlayItem overlayitem = new OverlayItem(point, "Puntito", "Su snippet");
	        itemizedOverlay.addOverlay(overlayitem);
	        
	        mapOverlays.clear();
	        mapOverlays.add(itemizedOverlay);
	        
	        mapView.performClick();
        }
	}

	@Override
	public void onProviderDisabled(String provider) {
		// TODO Auto-generated method stub
		
	}


	@Override
	public void onProviderEnabled(String provider) {
		// TODO Auto-generated method stub
		
	}


	@Override
	public void onStatusChanged(String provider, int status, Bundle extras) {
		// TODO Auto-generated method stub
		
	}
	
	/* Creates the menu items */
	public boolean onCreateOptionsMenu(Menu menu) {
	    menu.add(0, MENU_NEW_GAME, 0, R.string.new_game).setIcon(R.drawable.new_game);
	    menu.add(0, MENU_QUIT, 0, R.string.quit).setIcon(R.drawable.quit);
	    return true;
	}

	/* Handles item selections */
	public boolean onOptionsItemSelected(MenuItem item) {
	    switch (item.getItemId()) {
	    case MENU_NEW_GAME:
	    	showDialog(DIALOG_SELECT_SERVER);
	        return true;
	    case MENU_QUIT:
	        this.finish();
	        return true;
	    }
	    return false;
	}
	
	protected Dialog onCreateDialog(int dialogID) {
		AlertDialog dialog = null;
		
		switch(dialogID) {
		case DIALOG_SELECT_SERVER:
			AlertDialog.Builder builder;
			
			LayoutInflater inflater = (LayoutInflater) this.getSystemService(LAYOUT_INFLATER_SERVICE);
			View layout = inflater.inflate(R.layout.serverdialog, (ViewGroup) findViewById(R.id.serverRoot));
			
			builder = new AlertDialog.Builder(this)
			.setView(layout)
			.setMessage(R.string.specify_server)

			.setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
				@Override
				public void onClick(DialogInterface dialog, int which) {
					AlertDialog alertDialog = (AlertDialog) dialog;
					EditText text = (EditText) alertDialog.findViewById(R.id.serverBox);
					String s = text.getText().toString();
					
					newConnection(s, 12345);
					
					dialog.dismiss();
				}
			})
			.setNegativeButton(R.string.cancel, new DialogInterface.OnClickListener() {
				@Override
				public void onClick(DialogInterface dialog, int which) {
					dialog.cancel();
				}
			});
			
			dialog = builder.create();
		}
		
		return dialog;
	}
	
	public void newConnection(String address, int port) {
        AlertDialog.Builder alertBuilder = new AlertDialog.Builder(this);
    	alertBuilder.setTitle(R.string.connection);
    	
    	AlertDialog alert=null;
    	
        connection = new Connection(address, port);
        
        if(connection != null && connection.isConnected()) {
        	connectionThread = new Thread(connection);
        	connectionThread.start();
        	
        	alertBuilder.setMessage(R.string.connection_ready);
        	alertBuilder.setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
				@Override
				public void onClick(DialogInterface dialog, int which) {
					dialog.cancel();
				}
        	});
        	alert = alertBuilder.create();
        	newGame();
        } else {
        	alertBuilder.setMessage(R.string.connection_failed);
        	alertBuilder.setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
				@Override
				public void onClick(DialogInterface dialog, int which) {
					dialog.cancel();
				}
        	});
        	
        	alert = alertBuilder.create();
        }
    	alert.show();
	}
	
	public void newGame() {
		this.game = new RPGGame();
	}

	@Override
	public void onDismiss(DialogInterface dialog) {
		
	}
}