package realityrpg.common.entities;

import java.util.LinkedList;

import com.google.android.maps.GeoPoint;
import com.google.android.maps.OverlayItem;

public class RPGPlayer extends OverlayItem {
	
	public static final float WEIGHT_RATE = 9.8f;
	
	private int strength;
	private int dexterity;
	private int energy;
	private int experience;
	
	private int strengthModification = 0;
	private int dexterityModification = 0;
	private int energyModification = 0;
	
	private RPGWeapon leftHand = null;
	private RPGWeapon rightHand = null;
	
	private LinkedList<RPGItem> backpack;
	private float totalWeight;
	
	public RPGPlayer(GeoPoint point, String title, String snippet, int strength, int dexterity, int experience) {
		super(point, title, snippet);
		
		this.strength = strength;
		this.dexterity = dexterity;
		this.experience = experience;
		
		this.backpack = new LinkedList<RPGItem>();
	}

	public int getLongitude()
	{
		return this.getPoint().getLongitudeE6();
	}
	
	public int getLatitude()
	{
		return this.getPoint().getLatitudeE6();
	}

	public int getStrength() {
		return strength;
	}

	public void setStrength(int strength) {
		this.strength = strength;
	}

	public int getDexterity() {
		return dexterity;
	}

	public void setDexterity(int dexterity) {
		this.dexterity = dexterity;
	}

	public int getExperience() {
		return experience;
	}

	public void setExperience(int experience) {
		this.experience = experience;
	}

	public int getEnergy() {
		return energy;
	}

	public void setEnergy(int energy) {
		this.energy = energy;
	}

	public RPGWeapon getLeftHand() {
		return leftHand;
	}

	public boolean setLeftHand(RPGWeapon weapon) {
		if(this.rightHand == null || !this.rightHand.isTwoHanded())
		{
			this.leftHand = weapon;
			applyModifications(weapon);
			return true;
		}
		
		return false;
	}

	public RPGWeapon getRightHand() {
		return rightHand;
	}

	public boolean setRightHand(RPGWeapon weapon) {
		if(this.leftHand == null || !this.leftHand.isTwoHanded())
		{
			this.rightHand = weapon;
			applyModifications(weapon);
			return true;
		}
		
		return false;
	}
	
	public void applyModifications(RPGItem item)
	{
		this.strengthModification += item.getStrengthModificator();
		this.dexterityModification += item.getDexterityModificator();
		this.energyModification += item.getEnergyModificator();
	}
	
	public void undoModifications(RPGItem item)
	{
		this.strengthModification -= item.getStrengthModificator();
		this.dexterityModification -= item.getDexterityModificator();
		this.energyModification -= item.getEnergyModificator();
	}
	
	public boolean addItemToBackPack(RPGItem item)
	{
		if(this.strength * WEIGHT_RATE >= totalWeight + item.getWeight())
		{
			backpack.add(item);
			totalWeight += item.getWeight();
			return true;
		}
		else
			return false;
	}
	
	public void dropItem(RPGItem item)
	{
		if(backpack.contains(item))
		{
			backpack.remove(item);
			totalWeight -= item.getWeight();
		}
		else if(leftHand.equals(item))
		{
			leftHand = null;
			totalWeight -= item.getWeight();
			undoModifications(item);
		}
		else if(rightHand.equals(item))
		{
			rightHand = null;
			totalWeight -= item.getWeight();
			undoModifications(item);
		} 
	}
}
